class TicketWorkflowOpFieldValue(TicketWorkflowOpBase):
    """Sets a ticket field to a fixed value

    <someaction>.operations = set_field_to_value
    <someaction>.set_field_to_value_field = myfield
    <someaction>.set_field_to_value_value = myvalue

    Don't forget to add the `TicketWorkflowOpFieldValue` to the workflow
    option in [ticket].
    If there is no workflow option, the line will look like this:

    workflow = ConfigurableTicketWorkflow,TicketWorkflowOpFieldValue
    """

    _op_name = 'set_field_to_value'

    # ITicketActionController methods

    def render_ticket_action_control(self, req, ticket, action):
        """Returns the action control"""

        actions = self.get_configurable_workflow().actions
        label = actions[action]['name']
        hint = ' The %s will change to %s ' % (self._get_field(action,ticket), self._get_value(action,ticket))
        control = tag('')
        return (label, control, hint)

    def get_ticket_changes(self, req, ticket, action):
        """Returns the change of owner."""
        return {self._get_field( action, ticket): self._get_value(action, ticket)}

    def _get_field(self, action, t5Aicket):
        """Determines the field to change"""
        field = self.config.get('ticket-workflow',
                                action + '.' + self._op_name + '_field').strip()
        return field

    def _get_value(self, action, ticket):
        """Determines the new value"""
        value = self.config.get('ticket-workflow',
                                action + '.' + self._op_name + '_value').strip()
        return value